@@ -456,6 +456,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.core
@@ -487,7 +489,7 @@ class CfnInclude(
         id: builtins.str,
         *,
         template_file: builtins.str,
-        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, "CfnIncludeProps"]] = None,
+        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union["CfnIncludeProps", typing.Dict[str, typing.Any]]]] = None,
         parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         preserve_logical_ids: typing.Optional[builtins.bool] = None,
     ) -> None:
@@ -499,6 +501,10 @@ class CfnInclude(
         :param parameters: Specifies parameters to be replaced by the values in this mapping. Any parameters in the template that aren't specified here will be left unmodified. If you include a parameter here with an ID that isn't in the template, template creation will fail and an error will be thrown. Default: - no parameters will be replaced
         :param preserve_logical_ids: Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnInclude.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnIncludeProps(
             template_file=template_file,
             load_nested_stacks=load_nested_stacks,
@@ -519,6 +525,9 @@ class CfnInclude(
 
         :param condition_name: the name of the Condition in the CloudFormation template file.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnInclude.get_condition)
+            check_type(argname="argument condition_name", value=condition_name, expected_type=type_hints["condition_name"])
         return typing.cast(aws_cdk.core.CfnCondition, jsii.invoke(self, "getCondition", [condition_name]))
 
     @jsii.member(jsii_name="getHook")
@@ -532,6 +541,9 @@ class CfnInclude(
 
         :param hook_logical_id: the logical ID of the Hook in the included CloudFormation template's 'Hooks' section.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnInclude.get_hook)
+            check_type(argname="argument hook_logical_id", value=hook_logical_id, expected_type=type_hints["hook_logical_id"])
         return typing.cast(aws_cdk.core.CfnHook, jsii.invoke(self, "getHook", [hook_logical_id]))
 
     @jsii.member(jsii_name="getMapping")
@@ -545,6 +557,9 @@ class CfnInclude(
 
         :param mapping_name: the name of the Mapping in the template to retrieve.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnInclude.get_mapping)
+            check_type(argname="argument mapping_name", value=mapping_name, expected_type=type_hints["mapping_name"])
         return typing.cast(aws_cdk.core.CfnMapping, jsii.invoke(self, "getMapping", [mapping_name]))
 
     @jsii.member(jsii_name="getNestedStack")
@@ -557,6 +572,9 @@ class CfnInclude(
 
         :param logical_id: the ID of the stack to retrieve, as it appears in the template.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnInclude.get_nested_stack)
+            check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
         return typing.cast("IncludedNestedStack", jsii.invoke(self, "getNestedStack", [logical_id]))
 
     @jsii.member(jsii_name="getOutput")
@@ -570,6 +588,9 @@ class CfnInclude(
 
         :param logical_id: the name of the output to retrieve.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnInclude.get_output)
+            check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
         return typing.cast(aws_cdk.core.CfnOutput, jsii.invoke(self, "getOutput", [logical_id]))
 
     @jsii.member(jsii_name="getParameter")
@@ -583,6 +604,9 @@ class CfnInclude(
 
         :param parameter_name: the name of the parameter to retrieve.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnInclude.get_parameter)
+            check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
         return typing.cast(aws_cdk.core.CfnParameter, jsii.invoke(self, "getParameter", [parameter_name]))
 
     @jsii.member(jsii_name="getResource")
@@ -603,6 +627,9 @@ class CfnInclude(
 
         :param logical_id: the logical ID of the resource in the CloudFormation template file.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnInclude.get_resource)
+            check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
         return typing.cast(aws_cdk.core.CfnResource, jsii.invoke(self, "getResource", [logical_id]))
 
     @jsii.member(jsii_name="getRule")
@@ -616,6 +643,9 @@ class CfnInclude(
 
         :param rule_name: the name of the Rule in the CloudFormation template.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnInclude.get_rule)
+            check_type(argname="argument rule_name", value=rule_name, expected_type=type_hints["rule_name"])
         return typing.cast(aws_cdk.core.CfnRule, jsii.invoke(self, "getRule", [rule_name]))
 
     @jsii.member(jsii_name="loadNestedStack")
@@ -624,7 +654,7 @@ class CfnInclude(
         logical_id: builtins.str,
         *,
         template_file: builtins.str,
-        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, "CfnIncludeProps"]] = None,
+        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union["CfnIncludeProps", typing.Dict[str, typing.Any]]]] = None,
         parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         preserve_logical_ids: typing.Optional[builtins.bool] = None,
     ) -> "IncludedNestedStack":
@@ -643,6 +673,9 @@ class CfnInclude(
 
         :return: the same {@link IncludedNestedStack} object that {@link getNestedStack} returns for this logical ID
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnInclude.load_nested_stack)
+            check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
         nested_stack_props = CfnIncludeProps(
             template_file=template_file,
             load_nested_stacks=load_nested_stacks,
@@ -668,7 +701,7 @@ class CfnIncludeProps:
         self,
         *,
         template_file: builtins.str,
-        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, "CfnIncludeProps"]] = None,
+        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union["CfnIncludeProps", typing.Dict[str, typing.Any]]]] = None,
         parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         preserve_logical_ids: typing.Optional[builtins.bool] = None,
     ) -> None:
@@ -692,6 +725,12 @@ class CfnIncludeProps:
                 }
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnIncludeProps.__init__)
+            check_type(argname="argument template_file", value=template_file, expected_type=type_hints["template_file"])
+            check_type(argname="argument load_nested_stacks", value=load_nested_stacks, expected_type=type_hints["load_nested_stacks"])
+            check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
+            check_type(argname="argument preserve_logical_ids", value=preserve_logical_ids, expected_type=type_hints["preserve_logical_ids"])
         self._values: typing.Dict[str, typing.Any] = {
             "template_file": template_file,
         }
@@ -800,6 +839,10 @@ class IncludedNestedStack:
             child_stack = included_child_stack.stack
             child_template = included_child_stack.included_template
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(IncludedNestedStack.__init__)
+            check_type(argname="argument included_template", value=included_template, expected_type=type_hints["included_template"])
+            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         self._values: typing.Dict[str, typing.Any] = {
             "included_template": included_template,
             "stack": stack,
