@@ -57,6 +57,7 @@ import aws_cdk.aws_codestarnotifications._jsii
 import aws_cdk.aws_cognito._jsii
 import aws_cdk.aws_config._jsii
 import aws_cdk.aws_connect._jsii
+import aws_cdk.aws_connectcampaigns._jsii
 import aws_cdk.aws_controltower._jsii
 import aws_cdk.aws_cur._jsii
 import aws_cdk.aws_customerprofiles._jsii
@@ -111,6 +112,7 @@ import aws_cdk.aws_iotanalytics._jsii
 import aws_cdk.aws_iotcoredeviceadvisor._jsii
 import aws_cdk.aws_iotevents._jsii
 import aws_cdk.aws_iotfleethub._jsii
+import aws_cdk.aws_iotfleetwise._jsii
 import aws_cdk.aws_iotsitewise._jsii
 import aws_cdk.aws_iotthingsgraph._jsii
 import aws_cdk.aws_iottwinmaker._jsii
@@ -168,6 +170,7 @@ import aws_cdk.aws_rekognition._jsii
 import aws_cdk.aws_resiliencehub._jsii
 import aws_cdk.aws_resourcegroups._jsii
 import aws_cdk.aws_robomaker._jsii
+import aws_cdk.aws_rolesanywhere._jsii
 import aws_cdk.aws_route53._jsii
 import aws_cdk.aws_route53recoverycontrol._jsii
 import aws_cdk.aws_route53recoveryreadiness._jsii
@@ -209,9 +212,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/cloudformation-include",
-    "1.173.0",
+    "1.178.0",
     __name__[0:-6],
-    "cloudformation-include@1.173.0.jsii.tgz",
+    "cloudformation-include@1.178.0.jsii.tgz",
 )
 
 __all__ = [
